@@ -36,9 +36,9 @@ class UniversalProcessor(object):
         user = auth.pop_user(username)
         pw = auth.new_random_password()
         email = user['email']
-        url = os.environ['HTTP_REFERER']
-        e_index = url.index('/edit/') + 5
-        url = url[:e_index] + '/'
+        url = 'Donkey Simple admin site'
+        if hasattr(self, 'edit_url') and hasattr(self, 'request'):
+            url = self.request.environ['HTTP_ORIGIN'] + self.edit_url
         if '@' in email:
             success, msg = password_email(user['email'], url, username, pw)
             if success:
@@ -52,14 +52,15 @@ class UniversalProcessor(object):
 
 class ProcessForm(UniversalProcessor):
     created_item = None
-    def __init__(self, add_msg, request, isadmin, username):
-        self._add_msg = add_msg
-        self.isadmin = isadmin
-        self.username = username
+    def __init__(self, view):
+        self._add_msg = view._add_msg
+        self.isadmin = view.isadmin
+        self.username = view.request.username
         self.regen_users = False
-        self.request = request
-        self.fields = request.form
-        self.files = request.files
+        self.request = view.request
+        self.fields = {k:v for k, v in view.request.form.items() if v not in ('', None)}
+        self.files = view.request.files
+        self.edit_url = view.site_edit_url
         self.process()
     
     def generate_site(self):
@@ -88,7 +89,7 @@ class ProcessForm(UniversalProcessor):
         if 'repo-url' in self.fields:
             url = self.fields['repo-url']
         git_repo.pull_clone_create(url)
-        ds.con.repeat_owners_permission()
+        ds.repeat_owners_permission(ds.REPOS_DIR)
         self._add_msg('Repo successfully created')
         
     def delete_repo(self):
@@ -102,7 +103,7 @@ class ProcessForm(UniversalProcessor):
         repo_path = self._get_repo_path(repo_name)
         git_repo = ds.Git(repo_path)
         response = str(git_repo.pull())
-        ds.con.repeat_owners_permission()
+        ds.repeat_owners_permission(ds.REPOS_DIR)
         self._add_msg('Pull Response: ')
         [self._add_msg(l) for l in response.split('\n')]
     
@@ -128,7 +129,7 @@ class ProcessForm(UniversalProcessor):
             msg = self.fields['commit-msg']
         git_repo.add_all()
         git_repo.set_user(settings.GIT_EMAIL, settings.GIT_NAME)
-        ds.con.repeat_owners_permission()
+        ds.repeat_owners_permission(ds.REPOS_DIR)
         [self._add_msg(line) for line in git_repo.commit(msg).split('\n')]
         
     def _get_repo_path(self, name):
@@ -238,6 +239,7 @@ class ProcessForm(UniversalProcessor):
             self._add_msg('"%s" successfully saved' % cf.display, 'success')
         
     def edit_user(self):
+        prev_username = None
         if 'previous-username' in self.fields:
             prev_username = self.fields['previous-username']
             if not self.isadmin and prev_username != self.username:
@@ -249,7 +251,7 @@ class ProcessForm(UniversalProcessor):
         formuser['admin'] = self.isadmin and 'admin' in self.fields and self.fields['admin'] == 'on'
         auth = UserAuth()
         msg_type = 'success'
-        if 'previous-username' not in self.fields:
+        if prev_username is None:
             if username in auth.users:
                 self._add_msg('user "%s" already exists, not creating user' % username, 'errors')
                 return
@@ -288,8 +290,7 @@ class ProcessForm(UniversalProcessor):
             return self._add_msg('Permission Denied', 'errors')
         else:
             self._password_reset_email(username)
-            if username == self.username:
-                self.regen_users = True
+            self.regen_users = True
 
     def change_user_password(self):
         username = self.fields['username']
@@ -308,8 +309,7 @@ class ProcessForm(UniversalProcessor):
         user = auth.pop_user(username)
         auth.add_user(username, user, pw)
         self._add_msg('"%s" password updated' % username, 'success')
-        if username == self.username:
-            self.regen_users = True
+        self.regen_users = True
         
     def upload_static(self):
         self._process_files('files', ds.con.Statics())
